package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbConferencePeople;

import java.util.List;
import java.util.Map;

/**
 * 数字教育大会参会嘉宾Service接口
 *
 * @author ruoyi
 * @date 2024-10-29
 */
public interface ITbConferencePeopleService
{
    /**
     * 查询数字教育大会参会嘉宾
     *
     * @param conferencePeopleId 数字教育大会参会嘉宾主键
     * @return 数字教育大会参会嘉宾
     */
    public TbConferencePeople selectTbConferencePeopleByConferencePeopleId(Long conferencePeopleId);

    /**
     * 查询数字教育大会参会嘉宾列表
     *
     * @param tbConferencePeople 数字教育大会参会嘉宾
     * @return 数字教育大会参会嘉宾集合
     */
    public List<TbConferencePeople> selectTbConferencePeopleList(TbConferencePeople tbConferencePeople);

    /**
     * 新增数字教育大会参会嘉宾
     *
     * @param tbConferencePeople 数字教育大会参会嘉宾
     * @return 结果
     */
    public int insertTbConferencePeople(TbConferencePeople tbConferencePeople);

    /**
     * 修改数字教育大会参会嘉宾
     *
     * @param tbConferencePeople 数字教育大会参会嘉宾
     * @return 结果
     */
    public int updateTbConferencePeople(TbConferencePeople tbConferencePeople);

    /**
     * 批量删除数字教育大会参会嘉宾
     *
     * @param conferencePeopleIds 需要删除的数字教育大会参会嘉宾主键集合
     * @return 结果
     */
    public int deleteTbConferencePeopleByConferencePeopleIds(Long[] conferencePeopleIds);

    /**
     * 删除数字教育大会参会嘉宾信息
     *
     * @param conferencePeopleId 数字教育大会参会嘉宾主键
     * @return 结果
     */
    public int deleteTbConferencePeopleByConferencePeopleId(Long conferencePeopleId);

    /**
     * 参会嘉宾列表
     *
     * @param params 参数
     * @return 参会嘉宾列表
     */
    public List<Map<String, Object>> getConferencePeopleList(Map<String, Object> params);
}
